-- French Canadian GIFI
-- Cline des Ligneris
-- checked DS. March 3, 2004
-- updated DS Nov 14, 2014
--
INSERT INTO gifi (accno,description) VALUES ('1000','Encaisse et dpts');
INSERT INTO gifi (accno,description) VALUES ('1001','Encaisse');
INSERT INTO gifi (accno,description) VALUES ('1002','Dpts dans des banques et des institutions canadiennes  monnaie canadienne');
INSERT INTO gifi (accno,description) VALUES ('1003','Dpts dans des banques et des institutions canadiennes  devises trangres');
INSERT INTO gifi (accno,description) VALUES ('1004','Dpts dans des banques trangres  monnaie canadienne');
INSERT INTO gifi (accno,description) VALUES ('1005','Dpts dans des banques trangres  devises trangres');
INSERT INTO gifi (accno,description) VALUES ('1006','Caisse de crdit  dpt central');
INSERT INTO gifi (accno,description) VALUES ('1007','Autres lments de l\'actif assimilables  de l\'encaisse');
INSERT INTO gifi (accno,description) VALUES ('1060','Comptes clients');
INSERT INTO gifi (accno,description) VALUES ('1061','Provision pour crances douteuses');
INSERT INTO gifi (accno,description) VALUES ('1062','Comptes clients commerciaux');
INSERT INTO gifi (accno,description) VALUES ('1063','Provision pour mauvaises crances  comptes clients commerciaux');
INSERT INTO gifi (accno,description) VALUES ('1064','Comptes clients de personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('1065','Provision pour mauvaises crances  personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('1066','Impts  recevoir');
INSERT INTO gifi (accno,description) VALUES ('1067','Intrts  recevoir');
INSERT INTO gifi (accno,description) VALUES ('1068','Retenues de garantie  recevoir');
INSERT INTO gifi (accno,description) VALUES ('1069','Crances au titre de baux');
INSERT INTO gifi (accno,description) VALUES ('1070','Provision pour lments douteux contenus dans certaines crances au titre de baux');
INSERT INTO gifi (accno,description) VALUES ('1071','Comptes  recevoir d\'employs');
INSERT INTO gifi (accno,description) VALUES ('1072','Provision pour mauvaises crances  employs');
INSERT INTO gifi (accno,description) VALUES ('1073','Montants  recevoir de membres d\'OSBL');
INSERT INTO gifi (accno,description) VALUES ('1120','Stocks');
INSERT INTO gifi (accno,description) VALUES ('1121','Stock de marchandises  vendre');
INSERT INTO gifi (accno,description) VALUES ('1122','Pices et fournitures en stock');
INSERT INTO gifi (accno,description) VALUES ('1123','Biens immobiliers figurant dans un inventaire');
INSERT INTO gifi (accno,description) VALUES ('1124','Stocks d\'agrgats');
INSERT INTO gifi (accno,description) VALUES ('1125','Travaux en cours');
INSERT INTO gifi (accno,description) VALUES ('1126','Matires premires');
INSERT INTO gifi (accno,description) VALUES ('1127','Titres figurant dans un inventaire');
INSERT INTO gifi (accno,description) VALUES ('1180','Placements  court terme');
INSERT INTO gifi (accno,description) VALUES ('1181','Dpts  terme canadiens');
INSERT INTO gifi (accno,description) VALUES ('1182','Actions de socits canadiennes');
INSERT INTO gifi (accno,description) VALUES ('1183','Obligations canadiennes');
INSERT INTO gifi (accno,description) VALUES ('1184','Bonds du Trsor canadien');
INSERT INTO gifi (accno,description) VALUES ('1185','Titres acquis avec entente de rachat');
INSERT INTO gifi (accno,description) VALUES ('1186','Autres placements canadiens  court terme');
INSERT INTO gifi (accno,description) VALUES ('1187','Placements trangers  court terme');
INSERT INTO gifi (accno,description) VALUES ('1240','Prts et effets  recevoir');
INSERT INTO gifi (accno,description) VALUES ('1241','Prts remboursables sur demande');
INSERT INTO gifi (accno,description) VALUES ('1242','Autres prts non rembourss');
INSERT INTO gifi (accno,description) VALUES ('1243','Effets  recevoir');
INSERT INTO gifi (accno,description) VALUES ('1244','Hypothques  recevoir');
INSERT INTO gifi (accno,description) VALUES ('1300','Sommes exigibles d\'actionnaire(s)/d\'administrateur(s)');
INSERT INTO gifi (accno,description) VALUES ('1301','Sommes exigibles d\'actionnaire(s) (particuliers)');
INSERT INTO gifi (accno,description) VALUES ('1302','Sommes exigibles d\'actionnaire(s) (socits)');
INSERT INTO gifi (accno,description) VALUES ('1303','Sommes exigibles d\'administrateur(s)');
INSERT INTO gifi (accno,description) VALUES ('1310','Sommes exigibles d\'associ(s)/commandit(s)');
INSERT INTO gifi (accno,description) VALUES ('1311','Sommes exigibles des commanditaires');
INSERT INTO gifi (accno,description) VALUES ('1312','Sommes exigibles d\'associs qui sont des socits de personnes');
INSERT INTO gifi (accno,description) VALUES ('1313','Sommes exigibles des commandits');
INSERT INTO gifi (accno,description) VALUES ('1314','Sommes exigibles d\'associs dtermins qui ne sont pas des commanditaires');
INSERT INTO gifi (accno,description) VALUES ('1360','Placements dans une(des) coentreprise(s)/ socit(s) de personnes');
INSERT INTO gifi (accno,description) VALUES ('1380','Sommes exigibles de coentreprise(s)/socit(s) de personnes');
INSERT INTO gifi (accno,description) VALUES ('1400','Sommes exigibles des personnes apparentes/placements dans des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('1401','Billets  demande de personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('1402','Intrts  recevoir de personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('1403','Prts/avances  des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('1460','Dettes des clients pour acceptation');
INSERT INTO gifi (accno,description) VALUES ('1480','Autres lments d\'actif  court terme');
INSERT INTO gifi (accno,description) VALUES ('1481','Impts sur le revenu reports');
INSERT INTO gifi (accno,description) VALUES ('1482','Revenus de placements accumuls');
INSERT INTO gifi (accno,description) VALUES ('1483','Impts recouvrables/remboursables');
INSERT INTO gifi (accno,description) VALUES ('1484','Dpenses payes d\'avance');
INSERT INTO gifi (accno,description) VALUES ('1485','Avances de forage');
INSERT INTO gifi (accno,description) VALUES ('1486','Cautionnement/dpts sur soumissions');
INSERT INTO gifi (accno,description) VALUES ('1599','Total de l\'actif  court terme');
INSERT INTO gifi (accno,description) VALUES ('1600','Terrains');
INSERT INTO gifi (accno,description) VALUES ('1601','Frais d\'amlioration des terrains');
INSERT INTO gifi (accno,description) VALUES ('1602','Amortissement cumul de l\'amlioration des terrains');
INSERT INTO gifi (accno,description) VALUES ('1620','Biens puisables');
INSERT INTO gifi (accno,description) VALUES ('1621','Amortissement cumul des biens puisables');
INSERT INTO gifi (accno,description) VALUES ('1622','Biens en ressources ptrolifres et en gaz naturel');
INSERT INTO gifi (accno,description) VALUES ('1623','Amortissement cumul des biens en ressources');
INSERT INTO gifi (accno,description) VALUES ('1624','Biens miniers');
INSERT INTO gifi (accno,description) VALUES ('1625','Amortissement cumul des biens miniers');
INSERT INTO gifi (accno,description) VALUES ('1626','Frais d\'exploration et d\'exploitation reports');
INSERT INTO gifi (accno,description) VALUES ('1627','Amortissement cumul des frais d\'exploration et d\'exploitation reports');
INSERT INTO gifi (accno,description) VALUES ('1628','Carrires');
INSERT INTO gifi (accno,description) VALUES ('1629','Amortissement cumul des carrires');
INSERT INTO gifi (accno,description) VALUES ('1630','Carrires de gravier');
INSERT INTO gifi (accno,description) VALUES ('1631','Amortissement cumul des carrires de gravier');
INSERT INTO gifi (accno,description) VALUES ('1632','Concessions forestires');
INSERT INTO gifi (accno,description) VALUES ('1633','Amortissement cumul des concessions forestires');
INSERT INTO gifi (accno,description) VALUES ('1680','Btiments');
INSERT INTO gifi (accno,description) VALUES ('1681','Amortissement cumul des btiments');
INSERT INTO gifi (accno,description) VALUES ('1682','Installations de fabrication et de traitement');
INSERT INTO gifi (accno,description) VALUES ('1683','Amortissement cumul des installations de fabrication et de traitement');
INSERT INTO gifi (accno,description) VALUES ('1684','Btiments en construction');
INSERT INTO gifi (accno,description) VALUES ('1740','Machines, matriel, meubles et accessoires');
INSERT INTO gifi (accno,description) VALUES ('1741','Amortissement cumul des machines, du matriel, des meubles et des accessoires');
INSERT INTO gifi (accno,description) VALUES ('1742','Vhicules automobiles');
INSERT INTO gifi (accno,description) VALUES ('1743','Amortissement cumul des vhicules automobiles');
INSERT INTO gifi (accno,description) VALUES ('1744','Outils et matrices');
INSERT INTO gifi (accno,description) VALUES ('1745','Amortissement cumul sur les outils et les matrices');
INSERT INTO gifi (accno,description) VALUES ('1746','Matriel de construction et d\'excavation');
INSERT INTO gifi (accno,description) VALUES ('1747','Amortissement cumul du matriel de construction et d\'excavation');
INSERT INTO gifi (accno,description) VALUES ('1748','Matriel d\'exploitation forestire');
INSERT INTO gifi (accno,description) VALUES ('1749','Amortissement cumul du matriel d\'exploitation forestire');
INSERT INTO gifi (accno,description) VALUES ('1750','Filets et matriel de pche');
INSERT INTO gifi (accno,description) VALUES ('1751','Amortissement cumul des filets et du matriel de pche');
INSERT INTO gifi (accno,description) VALUES ('1752','Matriel d\'exploitation minire');
INSERT INTO gifi (accno,description) VALUES ('1753','Amortissement cumul du matriel d\'exploitation minire');
INSERT INTO gifi (accno,description) VALUES ('1754','Rseaux ptroliers et gaziers');
INSERT INTO gifi (accno,description) VALUES ('1755','Amortissement cumul des rseaux ptroliers et gaziers');
INSERT INTO gifi (accno,description) VALUES ('1756','Matriel de production pour les industries de ressources naturelles');
INSERT INTO gifi (accno,description) VALUES ('1757','Amortissement cumul du matriel de production de ressources naturelles');
INSERT INTO gifi (accno,description) VALUES ('1758','Matriel de production autre que pour les industries de ressources naturelles');
INSERT INTO gifi (accno,description) VALUES ('1759','Amortissement cumul du matriel de production autre que pour les industries des ressources  naturelles');
INSERT INTO gifi (accno,description) VALUES ('1760','Matriel d\'exploration');
INSERT INTO gifi (accno,description) VALUES ('1761','Amortissement cumul du matriel d\'exploration');
INSERT INTO gifi (accno,description) VALUES ('1762','Matriel d\'expdition');
INSERT INTO gifi (accno,description) VALUES ('1763','Amortissement cumul du matriel d\'expdition');
INSERT INTO gifi (accno,description) VALUES ('1764','Navires et bateaux');
INSERT INTO gifi (accno,description) VALUES ('1765','Amortissement cumul des navires et des bateaux');
INSERT INTO gifi (accno,description) VALUES ('1766','Aronefs');
INSERT INTO gifi (accno,description) VALUES ('1767','Amortissement cumul des aronefs');
INSERT INTO gifi (accno,description) VALUES ('1768','Panneaux indicateurs');
INSERT INTO gifi (accno,description) VALUES ('1769','Amortissement cumul des panneaux indicateurs');
INSERT INTO gifi (accno,description) VALUES ('1770','Petits outils');
INSERT INTO gifi (accno,description) VALUES ('1771','Amortissement cumul des petits outils');
INSERT INTO gifi (accno,description) VALUES ('1772','Matriel de radio et de communication');
INSERT INTO gifi (accno,description) VALUES ('1773','Amortissement cumul du matriel de radio et de communication');
INSERT INTO gifi (accno,description) VALUES ('1774','Matriel informatique/logiciels');
INSERT INTO gifi (accno,description) VALUES ('1775','Amortissement cumul du matriel informatique / logiciels');
INSERT INTO gifi (accno,description) VALUES ('1776','Instruments de musique');
INSERT INTO gifi (accno,description) VALUES ('1777','Amortissement cumul des instruments de musique');
INSERT INTO gifi (accno,description) VALUES ('1778','Satellites');
INSERT INTO gifi (accno,description) VALUES ('1779','Amortissement cumul des satellites');
INSERT INTO gifi (accno,description) VALUES ('1780','Stations terrestres');
INSERT INTO gifi (accno,description) VALUES ('1781','Amortissement cumul des stations terrestres');
INSERT INTO gifi (accno,description) VALUES ('1782','Machines et matriel en cours de fabrication');
INSERT INTO gifi (accno,description) VALUES ('1783','Matriel de transport');
INSERT INTO gifi (accno,description) VALUES ('1784','Amortissement cumul du matriel de transport');
INSERT INTO gifi (accno,description) VALUES ('1785','Autres machines et matriel');
INSERT INTO gifi (accno,description) VALUES ('1786','Amortissement cumul des autres machines et d\'autre matriel');
INSERT INTO gifi (accno,description) VALUES ('1787','Meubles et accessoires');
INSERT INTO gifi (accno,description) VALUES ('1788','Amortissement cumul des meubles et des accessoires');
INSERT INTO gifi (accno,description) VALUES ('1900','Autres immobilisations');
INSERT INTO gifi (accno,description) VALUES ('1901','Amortissement cumul des autres immobilisations');
INSERT INTO gifi (accno,description) VALUES ('1902','Chemins d\'exploitation forestire');
INSERT INTO gifi (accno,description) VALUES ('1903','Amortissement cumul des chemins d\'exploitation forestire');
INSERT INTO gifi (accno,description) VALUES ('1904','Aires asphaltes et parcs de stationnement');
INSERT INTO gifi (accno,description) VALUES ('1905','Amortissement des aires asphaltes et des parcs de stationnement');
INSERT INTO gifi (accno,description) VALUES ('1906','Quais');
INSERT INTO gifi (accno,description) VALUES ('1907','Amortissement cumul des quais');
INSERT INTO gifi (accno,description) VALUES ('1908','Cltures');
INSERT INTO gifi (accno,description) VALUES ('1909','Amortissement cumul des cltures');
INSERT INTO gifi (accno,description) VALUES ('1910','Contrats de location  acquisition (btiments)');
INSERT INTO gifi (accno,description) VALUES ('1911','Amortissement cumul des contrats de location - acquisition (btiments)');
INSERT INTO gifi (accno,description) VALUES ('1912','Contrats de location  acquisition (matriel)');
INSERT INTO gifi (accno,description) VALUES ('1913','Amortissement cumul des contrats de location  acquisition (matriel)');
INSERT INTO gifi (accno,description) VALUES ('1914','Contrats de location  acquisition (vhicules)');
INSERT INTO gifi (accno,description) VALUES ('1915','Amortissement cumul des contrats de location  acquisition (vhicules)');
INSERT INTO gifi (accno,description) VALUES ('1916','Contrats de location  acquisition (autres)panneaux');
INSERT INTO gifi (accno,description) VALUES ('1917','Amortissement cumul des contrats de location  acquisition (autres)');
INSERT INTO gifi (accno,description) VALUES ('1918','Amliorations locatives');
INSERT INTO gifi (accno,description) VALUES ('1919','Amortissement cumul des amliorations locatives');
INSERT INTO gifi (accno,description) VALUES ('1920','Autres immobilisations en construction');
INSERT INTO gifi (accno,description) VALUES ('1921','Aires de campings');
INSERT INTO gifi (accno,description) VALUES ('1922','Amortissement cumul des aires de campings');
INSERT INTO gifi (accno,description) VALUES ('2008','Total des immobilisations');
INSERT INTO gifi (accno,description) VALUES ('2009','Total de l\'amortissement cumul des immobilisations');
INSERT INTO gifi (accno,description) VALUES ('2010','Actif incorporel');
INSERT INTO gifi (accno,description) VALUES ('2011','Amortissement cumul de l\'actif incorporel');
INSERT INTO gifi (accno,description) VALUES ('2012','Achalandage');
INSERT INTO gifi (accno,description) VALUES ('2013','Amortissement cumul de l\'achalandage');
INSERT INTO gifi (accno,description) VALUES ('2014','Contingents');
INSERT INTO gifi (accno,description) VALUES ('2015','Amortissement cumul des contingents');
INSERT INTO gifi (accno,description) VALUES ('2016','Permis');
INSERT INTO gifi (accno,description) VALUES ('2017','Amortissement cumul des permis');
INSERT INTO gifi (accno,description) VALUES ('2018','Frais de constitution en socit');
INSERT INTO gifi (accno,description) VALUES ('2019','Amortissement cumul des frais de constitution en socit');
INSERT INTO gifi (accno,description) VALUES ('2020','Marques de commerce et brevets');
INSERT INTO gifi (accno,description) VALUES ('2021','Amortissement cumul des marques de commerce et des brevets');
INSERT INTO gifi (accno,description) VALUES ('2022','Listes de clients');
INSERT INTO gifi (accno,description) VALUES ('2023','Amortissement cumul des listes de clients');
INSERT INTO gifi (accno,description) VALUES ('2024','Droits');
INSERT INTO gifi (accno,description) VALUES ('2025','Amortissement cumul des droits');
INSERT INTO gifi (accno,description) VALUES ('2026','Recherche et dveloppement');
INSERT INTO gifi (accno,description) VALUES ('2027','Amortissement cumul de la recherche et du dveloppement');
INSERT INTO gifi (accno,description) VALUES ('2070','Droits relatifs  des ressources');
INSERT INTO gifi (accno,description) VALUES ('2071','Amortissement cumul des droits relatifs  des ressources');
INSERT INTO gifi (accno,description) VALUES ('2072','Droits de coupe');
INSERT INTO gifi (accno,description) VALUES ('2073','Amortissement cumul des droits de coupe');
INSERT INTO gifi (accno,description) VALUES ('2074','Droits miniers');
INSERT INTO gifi (accno,description) VALUES ('2075','Amortissement cumul des droits miniers');
INSERT INTO gifi (accno,description) VALUES ('2076','Droits ptroliers et gaziers');
INSERT INTO gifi (accno,description) VALUES ('2077','Amortissement cumul des droits ptroliers et gaziers');
INSERT INTO gifi (accno,description) VALUES ('2178','Total de l\'actif incorporel');
INSERT INTO gifi (accno,description) VALUES ('2179','Total de l\'amortissement cumul de l\'actif incorporel');
INSERT INTO gifi (accno,description) VALUES ('2180','Sommes exigibles d\'actionnaire(s)/ d\'administrateur(s)');
INSERT INTO gifi (accno,description) VALUES ('2181','Sommes exigibles d\'actionnaire(s) (particuliers)');
INSERT INTO gifi (accno,description) VALUES ('2182','Sommes exigibles d\'actionnaire(s) (socits)');
INSERT INTO gifi (accno,description) VALUES ('2183','Sommes exigibles d\'administrateur(s)');
INSERT INTO gifi (accno,description) VALUES ('2190','Sommes exigibles des membres');
INSERT INTO gifi (accno,description) VALUES ('2200','Placements dans une(des) coentreprise(s)/socit(s) de personnes');
INSERT INTO gifi (accno,description) VALUES ('2210','Sommes exigibles d\'associ(s)/commandit(s)');
INSERT INTO gifi (accno,description) VALUES ('2211','Sommes exigibles des commanditaires');
INSERT INTO gifi (accno,description) VALUES ('2212','Sommes exigibles d\'associs qui sont des socits de personnes');
INSERT INTO gifi (accno,description) VALUES ('2213','Sommes exigibles des commandits');
INSERT INTO gifi (accno,description) VALUES ('2214','Sommes exigibles d\'associs dtermins qui ne sont pas des commanditaires');
INSERT INTO gifi (accno,description) VALUES ('2220','Sommes exigibles de coentreprise(s)/socit(s)de personnes');
INSERT INTO gifi (accno,description) VALUES ('2240','Sommes exigibles des personnes apparentes/');
INSERT INTO gifi (accno,description) VALUES ('2241','Sommes exigibles de/placements dans des personnes canadiennes apparentes');
INSERT INTO gifi (accno,description) VALUES ('2242','Actions dans des socits canadiennes apparentes');
INSERT INTO gifi (accno,description) VALUES ('2243','Prts/avances  des socits canadiennes apparentes');
INSERT INTO gifi (accno,description) VALUES ('2244','Placements dans des socits canadiennes apparentes  la valeur d\'acquisition');
INSERT INTO gifi (accno,description) VALUES ('2245','Placements dans des socits canadiennes apparentes  la valeur de consolidation');
INSERT INTO gifi (accno,description) VALUES ('2246','Sommes exigibles de/placements dans des parties trangres apparentes');
INSERT INTO gifi (accno,description) VALUES ('2247','Actions dans des socits trangres apparentes');
INSERT INTO gifi (accno,description) VALUES ('2248','Prts/avances  des socits trangres apparentes');
INSERT INTO gifi (accno,description) VALUES ('2249','Placements dans des socits trangres apparentes  la valeur d\'acquisition');
INSERT INTO gifi (accno,description) VALUES ('2250','Placements dans des socits trangres apparentes  la valeur de consolidation');
INSERT INTO gifi (accno,description) VALUES ('2280','Placements dans des locations en partenariat');
INSERT INTO gifi (accno,description) VALUES ('2300','Placements  long terme');
INSERT INTO gifi (accno,description) VALUES ('2301','Actions dans des socits trangres');
INSERT INTO gifi (accno,description) VALUES ('2302','Autres genres de placements  l\'tranger');
INSERT INTO gifi (accno,description) VALUES ('2303','Actions dans des socits canadiennes');
INSERT INTO gifi (accno,description) VALUES ('2304','Titres de crances du gouvernement du Canada');
INSERT INTO gifi (accno,description) VALUES ('2305','Titres de crances des gouvernements provinciaux et des administrations municipales du Canada');
INSERT INTO gifi (accno,description) VALUES ('2306','Obligations et dbentures de socits canadiennes');
INSERT INTO gifi (accno,description) VALUES ('2307','Titres de crances');
INSERT INTO gifi (accno,description) VALUES ('2308','Titres de participation');
INSERT INTO gifi (accno,description) VALUES ('2309','Titres acquis  la suite d\'une entente de rachat');
INSERT INTO gifi (accno,description) VALUES ('2310','Actions de la caisse de crdit centrale');
INSERT INTO gifi (accno,description) VALUES ('2311','Autres placements canadiens  long terme');
INSERT INTO gifi (accno,description) VALUES ('2360','Prts  long terme');
INSERT INTO gifi (accno,description) VALUES ('2361','Prts hypothcaires');
INSERT INTO gifi (accno,description) VALUES ('2362','Prts personnels et prts sur carte de crdit');
INSERT INTO gifi (accno,description) VALUES ('2363','Prts au gouvernement et prts commerciaux');
INSERT INTO gifi (accno,description) VALUES ('2364','Marge de crdit');
INSERT INTO gifi (accno,description) VALUES ('2420','Autres lments d\'actif  long terme');
INSERT INTO gifi (accno,description) VALUES ('2421','Impts sur le revenu reports');
INSERT INTO gifi (accno,description) VALUES ('2422','Frais du rgime de pension reports');
INSERT INTO gifi (accno,description) VALUES ('2423','Pertes de change non matrialises reportes');
INSERT INTO gifi (accno,description) VALUES ('2424','Autres lments/frais reports');
INSERT INTO gifi (accno,description) VALUES ('2425','Amortissement cumul des frais reports');
INSERT INTO gifi (accno,description) VALUES ('2426','Fonds de rserve');
INSERT INTO gifi (accno,description) VALUES ('2427','Valeur de rachat de l\'assurance-vie');
INSERT INTO gifi (accno,description) VALUES ('2589','Total de l\'actif  long terme');
INSERT INTO gifi (accno,description) VALUES ('2590','Actif dtenu en fiducie');
INSERT INTO gifi (accno,description) VALUES ('2599','Total de l\'actif');
INSERT INTO gifi (accno,description) VALUES ('2600','Dcouvert bancaire');
INSERT INTO gifi (accno,description) VALUES ('2620','Montants et charges  payer');
INSERT INTO gifi (accno,description) VALUES ('2621','Effets commerciaux  payer');
INSERT INTO gifi (accno,description) VALUES ('2622','Effets commerciaux  payer  des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('2623','Retenues de garantie  payer');
INSERT INTO gifi (accno,description) VALUES ('2624','Salaires  payer');
INSERT INTO gifi (accno,description) VALUES ('2625','Frais de gestion  payer');
INSERT INTO gifi (accno,description) VALUES ('2626','Gratifications  payer');
INSERT INTO gifi (accno,description) VALUES ('2627','Retenues salariales  payer');
INSERT INTO gifi (accno,description) VALUES ('2628','Retenues d\'impts et de taxes  payer');
INSERT INTO gifi (accno,description) VALUES ('2629','Intrts  payer');
INSERT INTO gifi (accno,description) VALUES ('2630','Montants  payer aux membres d\'OSBL');
INSERT INTO gifi (accno,description) VALUES ('2680','Taxes et impts  payer');
INSERT INTO gifi (accno,description) VALUES ('2700','Dettes  court terme');
INSERT INTO gifi (accno,description) VALUES ('2701','Emprunts auprs de banques canadiennes');
INSERT INTO gifi (accno,description) VALUES ('2702','lment de passif pour les titres vendus  dcouvert');
INSERT INTO gifi (accno,description) VALUES ('2703','lment de passif pour les titres vendus  la suite d\'une entente de rachat');
INSERT INTO gifi (accno,description) VALUES ('2704','Titres sur l\'or et sur l\'argent');
INSERT INTO gifi (accno,description) VALUES ('2705','Chques et autres items en circulation');
INSERT INTO gifi (accno,description) VALUES ('2706','Billets garantis');
INSERT INTO gifi (accno,description) VALUES ('2707','Prts sur carte de crdit');
INSERT INTO gifi (accno,description) VALUES ('2770','Revenus reports');
INSERT INTO gifi (accno,description) VALUES ('2780','Sommes dues  un(des) actionnaire(s)/administrateur(s)');
INSERT INTO gifi (accno,description) VALUES ('2781','Sommes dues  un(des) actionnaire(s) (particuliers)');
INSERT INTO gifi (accno,description) VALUES ('2782','Sommes dues  un(des) actionnaire(s) (socits)');
INSERT INTO gifi (accno,description) VALUES ('2783','Sommes dues  un(des) administrateur(s)');
INSERT INTO gifi (accno,description) VALUES ('2790','Sommes payables aux associ(s)/commandit(s)');
INSERT INTO gifi (accno,description) VALUES ('2791','Sommes payables aux commanditaires');
INSERT INTO gifi (accno,description) VALUES ('2792','Sommes payables aux associs qui sont des socits de personnes');
INSERT INTO gifi (accno,description) VALUES ('2793','Sommes payables aux commandits');
INSERT INTO gifi (accno,description) VALUES ('2794','Sommes payables aux associs dtermins qui ne sont pas des commanditaires');
INSERT INTO gifi (accno,description) VALUES ('2840','Sommes dues  une(des) coentreprise(s)/ socit(s) de personnes');
INSERT INTO gifi (accno,description) VALUES ('2860','Sommes dues  des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('2861','Billets  demande dus  des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('2862','Intrts  payer  des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('2863','Avances  payer  des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('2920','Portion  court terme du passif  long terme');
INSERT INTO gifi (accno,description) VALUES ('2940','Acceptations de banque');
INSERT INTO gifi (accno,description) VALUES ('2960','Autres lments du passif  court terme');
INSERT INTO gifi (accno,description) VALUES ('2961','Sommes reues en dpts');
INSERT INTO gifi (accno,description) VALUES ('2962','Dividendes  payer');
INSERT INTO gifi (accno,description) VALUES ('2963','Impts sur le revenu reports');
INSERT INTO gifi (accno,description) VALUES ('2964','Rserve pour garanties et indemnits');
INSERT INTO gifi (accno,description) VALUES ('2965','Provisions et rserves gnrales');
INSERT INTO gifi (accno,description) VALUES ('2966','Parts des membres de l\'quipage');
INSERT INTO gifi (accno,description) VALUES ('3139','Total du passif  court terme');
INSERT INTO gifi (accno,description) VALUES ('3140','Dette  long terme');
INSERT INTO gifi (accno,description) VALUES ('3141','Hypothques');
INSERT INTO gifi (accno,description) VALUES ('3142','Emprunts d\'une socit de crdit agricole');
INSERT INTO gifi (accno,description) VALUES ('3143','Emprunt d\'une banque  charte');
INSERT INTO gifi (accno,description) VALUES ('3144','Emprunt d\'une caisse populaire/d\'une cooprative de crdit');
INSERT INTO gifi (accno,description) VALUES ('3145','Emprunt du gouvernement provincial');
INSERT INTO gifi (accno,description) VALUES ('3146','Emprunt d\'un fournisseur');
INSERT INTO gifi (accno,description) VALUES ('3147','Prt personnel');
INSERT INTO gifi (accno,description) VALUES ('3148','Emprunts d\'une fdration, d\'une centrale ou de');
INSERT INTO gifi (accno,description) VALUES ('3149','Marge de crdit');
INSERT INTO gifi (accno,description) VALUES ('3150','lment de passif pour les titres vendus ');
INSERT INTO gifi (accno,description) VALUES ('3151','lment de passif pour les titres vendus  la suite d\'une entente de rachat');
INSERT INTO gifi (accno,description) VALUES ('3152','Billets garantis');
INSERT INTO gifi (accno,description) VALUES ('3200','Cautionnement des institutions financires');
INSERT INTO gifi (accno,description) VALUES ('3210','Obligations et dbentures');
INSERT INTO gifi (accno,description) VALUES ('3220','Revenus reports');
INSERT INTO gifi (accno,description) VALUES ('3240','Impts sur le revenu reports');
INSERT INTO gifi (accno,description) VALUES ('3260','Sommes dues  un(des) actionnaire(s)/ administrateur(s)');
INSERT INTO gifi (accno,description) VALUES ('3261','Sommes dues  un(des) actionnaire(s) (particuliers)');
INSERT INTO gifi (accno,description) VALUES ('3262','Sommes dues  un(des) actionnaire(s) (socits)');
INSERT INTO gifi (accno,description) VALUES ('3263','Sommes dues  un(des) administrateur(s)');
INSERT INTO gifi (accno,description) VALUES ('3270','Sommes dues  des membres');
INSERT INTO gifi (accno,description) VALUES ('3280','Sommes dues  une(des) coentreprise(s)/socit(s) de personnes');
INSERT INTO gifi (accno,description) VALUES ('3291','Sommes payables aux associ(s)/commandit(s)');
INSERT INTO gifi (accno,description) VALUES ('3292','Sommes payables aux commanditaires');
INSERT INTO gifi (accno,description) VALUES ('3293','Sommes payables aux associs qui sont des socits de personnes');
INSERT INTO gifi (accno,description) VALUES ('3294','Sommes payables aux commandits');
INSERT INTO gifi (accno,description) VALUES ('3295','Sommes payables aux associs dtermins qui ne sont pas des commanditaires');
INSERT INTO gifi (accno,description) VALUES ('3300','Sommes dues  des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('3301','Sommes dues  des personnes canadiennes apparentes');
INSERT INTO gifi (accno,description) VALUES ('3302','Sommes dues  des personnes trangres apparentes');
INSERT INTO gifi (accno,description) VALUES ('3320','Autres lments de passif  long terme');
INSERT INTO gifi (accno,description) VALUES ('3321','Obligations, engagements et location-acquisition  long terme');
INSERT INTO gifi (accno,description) VALUES ('3322','Rserves pour garanties et indemnits');
INSERT INTO gifi (accno,description) VALUES ('3323','Provision pour la restauration des sites d\'exploitation');
INSERT INTO gifi (accno,description) VALUES ('3324','Contribution  une fiducie pour l\'environnement');
INSERT INTO gifi (accno,description) VALUES ('3325','Provisions et rserves gnrales');
INSERT INTO gifi (accno,description) VALUES ('3326','Redressement pour les actions privilgies');
INSERT INTO gifi (accno,description) VALUES ('3327','Rpartition aux membres');
INSERT INTO gifi (accno,description) VALUES ('3328','Revenus diffrs de contrats incomplets');
INSERT INTO gifi (accno,description) VALUES ('3450','Total du passif  long terme');
INSERT INTO gifi (accno,description) VALUES ('3460','Dettes de second rang');
INSERT INTO gifi (accno,description) VALUES ('3470','Sommes dtenues en fiducie');
INSERT INTO gifi (accno,description) VALUES ('3499','Total du passif');
INSERT INTO gifi (accno,description) VALUES ('3500','Actions ordinaires');
INSERT INTO gifi (accno,description) VALUES ('3520','Actions privilgies');
INSERT INTO gifi (accno,description) VALUES ('3540','Surplus d\'apport et autres surplus');
INSERT INTO gifi (accno,description) VALUES ('3541','Surplus d\'apport');
INSERT INTO gifi (accno,description) VALUES ('3542','Surplus d\'expertise');
INSERT INTO gifi (accno,description) VALUES ('3543','Rserve gnrale');
INSERT INTO gifi (accno,description) VALUES ('3570','Compte du sige social');
INSERT INTO gifi (accno,description) VALUES ('3580','Cumul des autres lments du rsultat tendu - Ce poste est  l\'usage des socits et des socits de personnes qui utilisent aussi bien les normes comptables d\'avant la conversion (Partie V du manuel de comptabilit de l\'ICCA) ou les Normes internationales d\'information financire (IFRS) (Partie I du manuel de comptabilit de l\'ICCA) lorsqu\'elles prparent leurs tats financiers. Ce poste est constitu du solde cumul de toutes les composantes des autres lments du rsultat tendu, soit les produits, charges, gains et pertes qui sont comptabiliss dans le rsultat tendu, mais exclus du rsultat net.');
INSERT INTO gifi (accno,description) VALUES ('3590','Capital des commandits (cot de la participation dans la socit de personnes) (poste  l\'usage des socits de personnes)');
INSERT INTO gifi (accno,description) VALUES ('3591','Capital des commanditaires (cot de la participation dans la socit de personnes) (poste  l\'usage des socits de personnes)');
INSERT INTO gifi (accno,description) VALUES ('3592','Apport de capital de l\'exercice (poste  l\'usage des socits de personnes)');
INSERT INTO gifi (accno,description) VALUES ('3600','Bnfices non rpartis/dficit');
INSERT INTO gifi (accno,description) VALUES ('3620','Total des capitaux propres');
INSERT INTO gifi (accno,description) VALUES ('3630','Total du capital des associs (poste  l\'usage des socits de personnes) - Ce poste reprsente le total de tous les montants de capital des associs et doit tre report (lisez  Contrle de validit des postes )');
INSERT INTO gifi (accno,description) VALUES ('3640','Total du passif et des capitaux propres');
INSERT INTO gifi (accno,description) VALUES ('3650','Total du passif et du capital des associs (poste  l\'usage des socits de personnes)');
INSERT INTO gifi (accno,description) VALUES ('3660','Bnfices non rpartis/dficit - dbut de l\'exercice');
INSERT INTO gifi (accno,description) VALUES ('3680','Revenu net/perte nette');
INSERT INTO gifi (accno,description) VALUES ('3690','Apport de capital au dbut de l\'exercice (poste  l'usage des socits de personnes)');
INSERT INTO gifi (accno,description) VALUES ('3700','Dividendes dclars');
INSERT INTO gifi (accno,description) VALUES ('3701','Dividendes en espces');
INSERT INTO gifi (accno,description) VALUES ('3702','Ristournes');
INSERT INTO gifi (accno,description) VALUES ('3720','Redressements sur exercices antrieurs');
INSERT INTO gifi (accno,description) VALUES ('3740','Autres lments touchant les bnfices non rpartis');
INSERT INTO gifi (accno,description) VALUES ('3741','Rachat d\'actions');
INSERT INTO gifi (accno,description) VALUES ('3742','Rserves spciales');
INSERT INTO gifi (accno,description) VALUES ('3743','Redressements relatifs aux devises');
INSERT INTO gifi (accno,description) VALUES ('3744','lments inhabituels de revenus');
INSERT INTO gifi (accno,description) VALUES ('3745','Transferts interfonds');
INSERT INTO gifi (accno,description) VALUES ('3750','Retraits (poste  l\'usage des socits de personnes)');
INSERT INTO gifi (accno,description) VALUES ('3849','Bnfices non rpartis/dficit  fin de l\'exercice');
INSERT INTO gifi (accno,description) VALUES ('7000','carts de rvaluation - variations au poste de l\'excdent de rvaluation en raison de la rvaluation d\'immobilisations corporelles et des immobilisations incorporelles');
INSERT INTO gifi (accno,description) VALUES ('7002','Gains/pertes au titre de prestations dfinies - carts actuariels sur l\'obligation au titre de prestations dfinies comptabiliss dans la priode au cours de laquelle ils sont survenus.');
INSERT INTO gifi (accno,description) VALUES ('7004','Gains/pertes rsultant de la conversion des tats financiers d\'un tablissement  l\'tranger - gains et pertes rsultant de la conversion des tats financiers d\'un tablissement  l\'tranger');
INSERT INTO gifi (accno,description) VALUES ('7006','Gains/pertes se rapportant aux instruments de capitaux propres - variations ultrieures de la juste valeur marchande d\'un placement dans un instrument de capitaux propres qui n\'est pas dtenu  des fins de transaction.');
INSERT INTO gifi (accno,description) VALUES ('7008','Partie relle des gains/pertes sur instruments de couverture de flux de trsorerie - partie relle des gains et des pertes sur les instruments de couverture de flux de trsorerie.');
INSERT INTO gifi (accno,description) VALUES ('7010','Impt sur le revenu concernant les autres lments du rsultat tendu - impt concernant chaque autre lment du rsultat tendu s\'il est rapport avant impt');
INSERT INTO gifi (accno,description) VALUES ('7020','Autres lments divers du rsultat tendu - gains et pertes concernant d\'autres lments du rsultat tendu non compris aux lignes 7000  7008');
INSERT INTO gifi (accno,description) VALUES ('8000','Ventes commerciales de biens et services');
INSERT INTO gifi (accno,description) VALUES ('8020','Ventes de biens et de services  des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('8030','Ventes entre divisions');
INSERT INTO gifi (accno,description) VALUES ('8040','Ventes de ressources naturelles');
INSERT INTO gifi (accno,description) VALUES ('8041','Ventes de ptrole et de gaz naturel');
INSERT INTO gifi (accno,description) VALUES ('8042','Ventes de ptrole et de gaz naturel  des personnes apparentes');
INSERT INTO gifi (accno,description) VALUES ('8043','Commercialisation du gaz');
INSERT INTO gifi (accno,description) VALUES ('8044','Revenus de traitement');
INSERT INTO gifi (accno,description) VALUES ('8045','Revenus de transport par pipeline');
INSERT INTO gifi (accno,description) VALUES ('8046','Ventes relies  l\'exploration sismique');
INSERT INTO gifi (accno,description) VALUES ('8047','Revenus provenant de l\'exploitation minire');
INSERT INTO gifi (accno,description) VALUES ('8048','Revenus provenant du charbon');
INSERT INTO gifi (accno,description) VALUES ('8049','Revenus de sables bitumineux');
INSERT INTO gifi (accno,description) VALUES ('8050','Revenus provenant des redevances');
INSERT INTO gifi (accno,description) VALUES ('8051','Revenus/pertes d\'une socit de personnes/coentreprise  ptrole et gaz');
INSERT INTO gifi (accno,description) VALUES ('8052','Revenus/pertes d\'une socit de personnes/coentreprise  mines');
INSERT INTO gifi (accno,description) VALUES ('8053','Autres revenus de production');
INSERT INTO gifi (accno,description) VALUES ('8089','Total des ventes de biens et services');
INSERT INTO gifi (accno,description) VALUES ('8090','Revenus de placements');
INSERT INTO gifi (accno,description) VALUES ('8091','Intrt de sources trangres');
INSERT INTO gifi (accno,description) VALUES ('8092','Intrt d\'obligations et de dbentures canadiennes');
INSERT INTO gifi (accno,description) VALUES ('8093','Intrt de prts hypothcaires canadiens');
INSERT INTO gifi (accno,description) VALUES ('8094','Intrt d\'autres sources canadiennes');
INSERT INTO gifi (accno,description) VALUES ('8095','Revenus de dividendes');
INSERT INTO gifi (accno,description) VALUES ('8096','Dividendes de sources canadiennes');
INSERT INTO gifi (accno,description) VALUES ('8097','Dividendes de sources trangres');
INSERT INTO gifi (accno,description) VALUES ('8100','Revenus d\'intrt (institutions financires)');
INSERT INTO gifi (accno,description) VALUES ('8101','Intrt de prts');
INSERT INTO gifi (accno,description) VALUES ('8102','Intrt de valeurs mobilires');
INSERT INTO gifi (accno,description) VALUES ('8103','Intrt des dpts en banque');
INSERT INTO gifi (accno,description) VALUES ('8120','Revenus de commissions');
INSERT INTO gifi (accno,description) VALUES ('8121','Revenus de commissions sur les transactions immobilires');
INSERT INTO gifi (accno,description) VALUES ('8140','Revenus de location');
INSERT INTO gifi (accno,description) VALUES ('8141','Revenus de location immobilire');
INSERT INTO gifi (accno,description) VALUES ('8142','Revenus de location de films');
INSERT INTO gifi (accno,description) VALUES ('8150','Contrats de location de vhicules');
INSERT INTO gifi (accno,description) VALUES ('8160','Revenus provenant de la pche');
INSERT INTO gifi (accno,description) VALUES ('8161','Ventes de poisson');
INSERT INTO gifi (accno,description) VALUES ('8162','Autres produits marins');
INSERT INTO gifi (accno,description) VALUES ('8163','Subventions, crdits et dgrvements de pche');
INSERT INTO gifi (accno,description) VALUES ('8164','Subventions de pche');
INSERT INTO gifi (accno,description) VALUES ('8165','Indemnit pour perte d\'un revenu ou d\'un bien de pche');
INSERT INTO gifi (accno,description) VALUES ('8166','Revenu de pcheur  la part');
INSERT INTO gifi (accno,description) VALUES ('8210','Profits/pertes sur la disposition d\'lments d\'actif');
INSERT INTO gifi (accno,description) VALUES ('8211','Profits/pertes sur la vente de placements');
INSERT INTO gifi (accno,description) VALUES ('8212','Profits/pertes sur la disposition d\'avoir minier');
INSERT INTO gifi (accno,description) VALUES ('8220','Montants reus d\'OSBL');
INSERT INTO gifi (accno,description) VALUES ('8221','Frais d\'adhsion');
INSERT INTO gifi (accno,description) VALUES ('8222','Cotisations');
INSERT INTO gifi (accno,description) VALUES ('8223','Dons');
INSERT INTO gifi (accno,description) VALUES ('8224','Ventes et recettes brutes provenant d\'activits de l\'organisme');
INSERT INTO gifi (accno,description) VALUES ('8230','Autres revenus');
INSERT INTO gifi (accno,description) VALUES ('8231','Gains/pertes sur devises trangres');
INSERT INTO gifi (accno,description) VALUES ('8232','Revenus/pertes de filiales/de socits affilies');
INSERT INTO gifi (accno,description) VALUES ('8233','Revenus/pertes d\'autres divisions');
INSERT INTO gifi (accno,description) VALUES ('8234','Revenus/pertes des coentreprises');
INSERT INTO gifi (accno,description) VALUES ('8235','Revenus/pertes des socits de personnes');
INSERT INTO gifi (accno,description) VALUES ('8236','Ralisation de revenus diffrs');
INSERT INTO gifi (accno,description) VALUES ('8237','Revenus de redevances autres que l\'exploitation des ressources naturelles');
INSERT INTO gifi (accno,description) VALUES ('8238','Crdits d\'impts pour redevances de l\'Alberta');
INSERT INTO gifi (accno,description) VALUES ('8239','Honoraires de gestion et d\'administration');
INSERT INTO gifi (accno,description) VALUES ('8240','Revenus de tlcommunications');
INSERT INTO gifi (accno,description) VALUES ('8241','Honoraires de consultation');
INSERT INTO gifi (accno,description) VALUES ('8242','Subventions et octrois');
INSERT INTO gifi (accno,description) VALUES ('8243','Ventes de sous-produits');
INSERT INTO gifi (accno,description) VALUES ('8244','Frais d\'administration provenant du service des dpts');
INSERT INTO gifi (accno,description) VALUES ('8245','Frais d\'administration provenant du service du crdit');
INSERT INTO gifi (accno,description) VALUES ('8246','Frais d\'administration provenant du service des cartes bancaires');
INSERT INTO gifi (accno,description) VALUES ('8247','Ristournes');
INSERT INTO gifi (accno,description) VALUES ('8248','Recouvrement d\'assurance');
INSERT INTO gifi (accno,description) VALUES ('8249','Recouvrement de frais');
INSERT INTO gifi (accno,description) VALUES ('8250','Recouvrement des mauvaises crances');
INSERT INTO gifi (accno,description) VALUES ('8299','Total des revenus');
INSERT INTO gifi (accno,description) VALUES ('8300','Stock d\'ouverture');
INSERT INTO gifi (accno,description) VALUES ('8301','Stock d\'ouverture  produits finis');
INSERT INTO gifi (accno,description) VALUES ('8302','Stock d\'ouverture  matires premires');
INSERT INTO gifi (accno,description) VALUES ('8303','Stock d\'ouverture  produits en cours de fabrication');
INSERT INTO gifi (accno,description) VALUES ('8320','Achats/cot des matriaux');
INSERT INTO gifi (accno,description) VALUES ('8340','Salaires directs');
INSERT INTO gifi (accno,description) VALUES ('8350','Avantages sociaux relatifs aux salaires directs');
INSERT INTO gifi (accno,description) VALUES ('8360','Fournisseurs et sous-traitants');
INSERT INTO gifi (accno,description) VALUES ('8370','Cots de production (autres que ressources naturelles)');
INSERT INTO gifi (accno,description) VALUES ('8400','Cots de production des ressources naturelles');
INSERT INTO gifi (accno,description) VALUES ('8401','Exploitation des pipelines');
INSERT INTO gifi (accno,description) VALUES ('8402','Forage');
INSERT INTO gifi (accno,description) VALUES ('8403','Cots de restauration des sites d\'exploitation');
INSERT INTO gifi (accno,description) VALUES ('8404','Redevances drogatoires brutes');
INSERT INTO gifi (accno,description) VALUES ('8405','Redevances de proprit franche');
INSERT INTO gifi (accno,description) VALUES ('8406','Paiements de location de concessions publiques');
INSERT INTO gifi (accno,description) VALUES ('8407','Prospection/travaux de gologie');
INSERT INTO gifi (accno,description) VALUES ('8408','Exploitation des puits, carburant et matriel');
INSERT INTO gifi (accno,description) VALUES ('8409','Abandon de puits et puits secs');
INSERT INTO gifi (accno,description) VALUES ('8410','Autres paiements de location');
INSERT INTO gifi (accno,description) VALUES ('8411','Frais d\'exploration');
INSERT INTO gifi (accno,description) VALUES ('8412','Frais d\'amnagement');
INSERT INTO gifi (accno,description) VALUES ('8435','Sommes exiges par la Couronne');
INSERT INTO gifi (accno,description) VALUES ('8436','Redevances  la Couronne');
INSERT INTO gifi (accno,description) VALUES ('8437','Frais de location de la Couronne');
INSERT INTO gifi (accno,description) VALUES ('8438','Impts sur le minerai de proprit franche');
INSERT INTO gifi (accno,description) VALUES ('8439','Impts miniers');
INSERT INTO gifi (accno,description) VALUES ('8440','Frais de location des sables bitumineux');
INSERT INTO gifi (accno,description) VALUES ('8441','Surtaxe de la Saskatchewan sur les ressources');
INSERT INTO gifi (accno,description) VALUES ('8450','Autres cots directs');
INSERT INTO gifi (accno,description) VALUES ('8451','Location et exploitation de matriel');
INSERT INTO gifi (accno,description) VALUES ('8452','Cour  bois');
INSERT INTO gifi (accno,description) VALUES ('8453','Cots d\'exploitation forestire');
INSERT INTO gifi (accno,description) VALUES ('8454','Cots des chemins forestiers');
INSERT INTO gifi (accno,description) VALUES ('8455','Droits de coupe');
INSERT INTO gifi (accno,description) VALUES ('8456','Cots des redevances');
INSERT INTO gifi (accno,description) VALUES ('8457','Frais de transport  l\'achat et droits');
INSERT INTO gifi (accno,description) VALUES ('8458','Moins-value de l\'inventaire');
INSERT INTO gifi (accno,description) VALUES ('8459','Cot direct de l\'amortissement des biens corporels');
INSERT INTO gifi (accno,description) VALUES ('8460','Cot direct de l\'amortissement des biens constitus');
INSERT INTO gifi (accno,description) VALUES ('8461','Autres frais indirects attribus au cot des ventes');
INSERT INTO gifi (accno,description) VALUES ('8500','Stock de fermeture');
INSERT INTO gifi (accno,description) VALUES ('8501','Stock de fermeture  produits finis');
INSERT INTO gifi (accno,description) VALUES ('8502','Stock de fermeture  matires premires');
INSERT INTO gifi (accno,description) VALUES ('8503','Stock de fermeture  travaux en cours de fabrication');
INSERT INTO gifi (accno,description) VALUES ('8518','Cot des ventes');
INSERT INTO gifi (accno,description) VALUES ('8519','Profit brut/perte brute');
INSERT INTO gifi (accno,description) VALUES ('8520','Publicit et promotion');
INSERT INTO gifi (accno,description) VALUES ('8521','Publicit');
INSERT INTO gifi (accno,description) VALUES ('8522','Dons');
INSERT INTO gifi (accno,description) VALUES ('8523','Repas et frais de reprsentation');
INSERT INTO gifi (accno,description) VALUES ('8524','Promotion - dmonstrations/prsentations, kiosques, prsentoirs, dpliants, chantillons et ateliers (donns)');
INSERT INTO gifi (accno,description) VALUES ('8570','Amortissement de biens incorporels - amortissement de biens incorporels tels que les charges reportes, l\'achalandage (avant 2002), les brevets, les franchises, les droits d\'auteur, les marques de commerce, les frais de constitution et les frais de recherche et dveloppement');
INSERT INTO gifi (accno,description) VALUES ('8571','cart d\'acquisition (achalandage) - pour les annes d\'imposition 2002 et suivantes');
INSERT INTO gifi (accno,description) VALUES ('8590','Crances irrcouvrables');
INSERT INTO gifi (accno,description) VALUES ('8610','Pertes sur prts');
INSERT INTO gifi (accno,description) VALUES ('8611','Provision pour les pertes sur prts');
INSERT INTO gifi (accno,description) VALUES ('8620','Avantages sociaux');
INSERT INTO gifi (accno,description) VALUES ('8621','Assurances collectives');
INSERT INTO gifi (accno,description) VALUES ('8622','Partie de l\'employeur des avantages sociaux');
INSERT INTO gifi (accno,description) VALUES ('8623','Cotisations aux rgimes de revenus diffrs');
INSERT INTO gifi (accno,description) VALUES ('8650','Amortissement des biens constitus par des ressources naturelles');
INSERT INTO gifi (accno,description) VALUES ('8670','Amortissement des biens corporels');
INSERT INTO gifi (accno,description) VALUES ('8690','Assurances');
INSERT INTO gifi (accno,description) VALUES ('8691','Assurance sur la vie des dirigeants');
INSERT INTO gifi (accno,description) VALUES ('8710','Intrts et frais bancaires');
INSERT INTO gifi (accno,description) VALUES ('8711','Intrts sur les dettes  court terme');
INSERT INTO gifi (accno,description) VALUES ('8712','Intrts sur les obligations et les dbentures');
INSERT INTO gifi (accno,description) VALUES ('8713','Intrts sur les prts hypothcaires');
INSERT INTO gifi (accno,description) VALUES ('8714','Intrts sur les dettes  long terme');
INSERT INTO gifi (accno,description) VALUES ('8715','Frais bancaires');
INSERT INTO gifi (accno,description) VALUES ('8716','Frais de cartes de crdit');
INSERT INTO gifi (accno,description) VALUES ('8717','Frais de recouvrement et de crdit');
INSERT INTO gifi (accno,description) VALUES ('8740','Intrts pays (institutions financires)');
INSERT INTO gifi (accno,description) VALUES ('8741','Intrts pays sur dpts');
INSERT INTO gifi (accno,description) VALUES ('8742','Intrts pays sur les obligations et les dbentures');
INSERT INTO gifi (accno,description) VALUES ('8760','Taxes d\'affaires, droits d\'adhsion et licences');
INSERT INTO gifi (accno,description) VALUES ('8761','Droits d\'adhsion');
INSERT INTO gifi (accno,description) VALUES ('8762','Taxes d\'affaires');
INSERT INTO gifi (accno,description) VALUES ('8763','Frais de franchise');
INSERT INTO gifi (accno,description) VALUES ('8764','Frais  verser aux gouvernements');
INSERT INTO gifi (accno,description) VALUES ('8780','Taxe des grandes socits du Nouveau-Brunswick');
INSERT INTO gifi (accno,description) VALUES ('8790','Taxe des grandes socits de la Nouvelle-cosse');
INSERT INTO gifi (accno,description) VALUES ('8810','Frais de bureau');
INSERT INTO gifi (accno,description) VALUES ('8811','Papeterie et fournitures de bureau');
INSERT INTO gifi (accno,description) VALUES ('8812','Services de bureau');
INSERT INTO gifi (accno,description) VALUES ('8813','Traitement des donnes');
INSERT INTO gifi (accno,description) VALUES ('8860','Honoraires professionnels');
INSERT INTO gifi (accno,description) VALUES ('8861','Frais lgaux');
INSERT INTO gifi (accno,description) VALUES ('8862','Frais comptables');
INSERT INTO gifi (accno,description) VALUES ('8863','Honoraires d\'experts-conseils');
INSERT INTO gifi (accno,description) VALUES ('8864','Honoraires d\'architectes');
INSERT INTO gifi (accno,description) VALUES ('8865','Frais d\'valuation');
INSERT INTO gifi (accno,description) VALUES ('8866','Frais de laboratoire');
INSERT INTO gifi (accno,description) VALUES ('8867','Honoraires mdicaux');
INSERT INTO gifi (accno,description) VALUES ('8868','Frais de vtrinaire');
INSERT INTO gifi (accno,description) VALUES ('8869','Frais de courtage');
INSERT INTO gifi (accno,description) VALUES ('8870','Frais de transfert');
INSERT INTO gifi (accno,description) VALUES ('8871','Frais de gestion et d\'administration');
INSERT INTO gifi (accno,description) VALUES ('8872','Affinage et dosage');
INSERT INTO gifi (accno,description) VALUES ('8873','Droits d\'enregistrement et frais d\'agents de transfert');
INSERT INTO gifi (accno,description) VALUES ('8874','Cots de restructuration');
INSERT INTO gifi (accno,description) VALUES ('8875','Commissions sur les titres et les valeurs mobilires');
INSERT INTO gifi (accno,description) VALUES ('8876','Frais de formation');
INSERT INTO gifi (accno,description) VALUES ('8877','Studio et enregistrement');
INSERT INTO gifi (accno,description) VALUES ('8910','Frais de location');
INSERT INTO gifi (accno,description) VALUES ('8911','Loyer de biens immobiliers');
INSERT INTO gifi (accno,description) VALUES ('8912','Frais d\'occupation');
INSERT INTO gifi (accno,description) VALUES ('8913','Frais de coproprit');
INSERT INTO gifi (accno,description) VALUES ('8914','Location de matriel');
INSERT INTO gifi (accno,description) VALUES ('8915','Location de vhicules motoriss');
INSERT INTO gifi (accno,description) VALUES ('8916','Amarrage (bateau)');
INSERT INTO gifi (accno,description) VALUES ('8917','Entreposage');
INSERT INTO gifi (accno,description) VALUES ('8918','Location de contingents');
INSERT INTO gifi (accno,description) VALUES ('8960','Rparations et entretien');
INSERT INTO gifi (accno,description) VALUES ('8961','Rparations et entretien  btiments');
INSERT INTO gifi (accno,description) VALUES ('8962','Rparations et entretien  vhicules');
INSERT INTO gifi (accno,description) VALUES ('8963','Rparations et entretien  bateaux');
INSERT INTO gifi (accno,description) VALUES ('8964','Rparations et entretien  machines et matriel');
INSERT INTO gifi (accno,description) VALUES ('9010','Autres frais de rparation et d\'entretien');
INSERT INTO gifi (accno,description) VALUES ('9011','Dpense d\'usinage');
INSERT INTO gifi (accno,description) VALUES ('9012','Frais relatifs aux routes');
INSERT INTO gifi (accno,description) VALUES ('9013','Scurit');
INSERT INTO gifi (accno,description) VALUES ('9014','Enlvement des dchets');
INSERT INTO gifi (accno,description) VALUES ('9060','Salaires et traitements');
INSERT INTO gifi (accno,description) VALUES ('9061','Commissions');
INSERT INTO gifi (accno,description) VALUES ('9062','Part de l\'quipage');
INSERT INTO gifi (accno,description) VALUES ('9063','Gratifications');
INSERT INTO gifi (accno,description) VALUES ('9064','Jetons de prsence des administrateurs');
INSERT INTO gifi (accno,description) VALUES ('9065','Salaires des cadres');
INSERT INTO gifi (accno,description) VALUES ('9066','Salaires des employs');
INSERT INTO gifi (accno,description) VALUES ('9110','Contrats de sous-traitance');
INSERT INTO gifi (accno,description) VALUES ('9130','Fournitures');
INSERT INTO gifi (accno,description) VALUES ('9131','Petit outillage');
INSERT INTO gifi (accno,description) VALUES ('9132','Frais d\'atelier');
INSERT INTO gifi (accno,description) VALUES ('9133','Uniformes');
INSERT INTO gifi (accno,description) VALUES ('9134','Blanchissage');
INSERT INTO gifi (accno,description) VALUES ('9135','Alimentation et restauration');
INSERT INTO gifi (accno,description) VALUES ('9136','Matriel de pche');
INSERT INTO gifi (accno,description) VALUES ('9137','Filets et piges');
INSERT INTO gifi (accno,description) VALUES ('9138','Sel, appts et glace');
INSERT INTO gifi (accno,description) VALUES ('9139','Fournitures de camp');
INSERT INTO gifi (accno,description) VALUES ('9150','Dpenses lies  l\'informatique');
INSERT INTO gifi (accno,description) VALUES ('9151','Amliorations et modernisations');
INSERT INTO gifi (accno,description) VALUES ('9152','Internet');
INSERT INTO gifi (accno,description) VALUES ('9180','Taxes foncires');
INSERT INTO gifi (accno,description) VALUES ('9201','Runions et congrs - participation  des colloques');
INSERT INTO gifi (accno,description) VALUES ('9200','Frais de dplacement');
INSERT INTO gifi (accno,description) VALUES ('9220','Services publics');
INSERT INTO gifi (accno,description) VALUES ('9221','lectricit');
INSERT INTO gifi (accno,description) VALUES ('9222','Eau');
INSERT INTO gifi (accno,description) VALUES ('9223','Chauffage');
INSERT INTO gifi (accno,description) VALUES ('9224','Frais de carburant - charbon, diesel, combustibles, gaz naturel, essence et gaz propane pour le chauffage et la prparation des aliments');
INSERT INTO gifi (accno,description) VALUES ('9225','Tlphone et tlcommunications - tlphone cellulaire, tlcopieur et tlavertisseur');
INSERT INTO gifi (accno,description) VALUES ('9270','Autres dpenses');
INSERT INTO gifi (accno,description) VALUES ('9271','carts de caisse');
INSERT INTO gifi (accno,description) VALUES ('9272','Remboursement de frais de la socit mre');
INSERT INTO gifi (accno,description) VALUES ('9273','Frais de vente');
INSERT INTO gifi (accno,description) VALUES ('9274','Frais de transport et d\'entreposage');
INSERT INTO gifi (accno,description) VALUES ('9275','Livraison, fret et messageries');
INSERT INTO gifi (accno,description) VALUES ('9276','Frais de garantie');
INSERT INTO gifi (accno,description) VALUES ('9277','Frais de redevances  rsidents');
INSERT INTO gifi (accno,description) VALUES ('9278','Frais de redevances  non-rsidents');
INSERT INTO gifi (accno,description) VALUES ('9279','Frais de dchargement');
INSERT INTO gifi (accno,description) VALUES ('9280','Frais d\'enfouissement');
INSERT INTO gifi (accno,description) VALUES ('9281','Frais de vhicules');
INSERT INTO gifi (accno,description) VALUES ('9282','Recherche et dveloppement');
INSERT INTO gifi (accno,description) VALUES ('9283','Retenues d\'impts');
INSERT INTO gifi (accno,description) VALUES ('9284','Frais d\'administration et frais gnraux');
INSERT INTO gifi (accno,description) VALUES ('9285','Dpenses entre divisions');
INSERT INTO gifi (accno,description) VALUES ('9286','Transferts interfonds');
INSERT INTO gifi (accno,description) VALUES ('9367','Total des frais d\'exploitation');
INSERT INTO gifi (accno,description) VALUES ('9368','Total des dpenses');
INSERT INTO gifi (accno,description) VALUES ('9369','Revenu non agricole net');
INSERT INTO gifi (accno,description) VALUES ('9370','Grains et olagineux');
INSERT INTO gifi (accno,description) VALUES ('9371','Bl');
INSERT INTO gifi (accno,description) VALUES ('9372','Avoine');
INSERT INTO gifi (accno,description) VALUES ('9373','Orge');
INSERT INTO gifi (accno,description) VALUES ('9374','Grains mixtes');
INSERT INTO gifi (accno,description) VALUES ('9375','Mas');
INSERT INTO gifi (accno,description) VALUES ('9376','Canola');
INSERT INTO gifi (accno,description) VALUES ('9377','Graine de lin');
INSERT INTO gifi (accno,description) VALUES ('9378','Fves soya');
INSERT INTO gifi (accno,description) VALUES ('9379','Paiements de la Commission canadienne du bl');
INSERT INTO gifi (accno,description) VALUES ('9420','Revenus d\'autres rcoltes');
INSERT INTO gifi (accno,description) VALUES ('9421','Fruits');
INSERT INTO gifi (accno,description) VALUES ('9422','Pommes de terre');
INSERT INTO gifi (accno,description) VALUES ('9423','Lgumes');
INSERT INTO gifi (accno,description) VALUES ('9424','Tabac');
INSERT INTO gifi (accno,description) VALUES ('9425','Produits de serre et de ppinire');
INSERT INTO gifi (accno,description) VALUES ('9426','Rcolte de fourrage');
INSERT INTO gifi (accno,description) VALUES ('9470','Revenus du btail et des produits d\'origine');
INSERT INTO gifi (accno,description) VALUES ('9471','Bovins');
INSERT INTO gifi (accno,description) VALUES ('9472','Porcins');
INSERT INTO gifi (accno,description) VALUES ('9473','Volaille');
INSERT INTO gifi (accno,description) VALUES ('9474','Ovins');
INSERT INTO gifi (accno,description) VALUES ('9475','Urine de jument gravide (UJG)');
INSERT INTO gifi (accno,description) VALUES ('9476','Lait et crme ( l\'exclusion des subventions pour');
INSERT INTO gifi (accno,description) VALUES ('9477','OEufs pour la consommation');
INSERT INTO gifi (accno,description) VALUES ('9478','Couvaison des oeufs');
INSERT INTO gifi (accno,description) VALUES ('9479','Aquaculture (couve et levage)');
INSERT INTO gifi (accno,description) VALUES ('9480','Chevaux (reproduction et viande)');
INSERT INTO gifi (accno,description) VALUES ('9520','Autres produits');
INSERT INTO gifi (accno,description) VALUES ('9521','Produits de l\'rable');
INSERT INTO gifi (accno,description) VALUES ('9522','Insmination artificielle');
INSERT INTO gifi (accno,description) VALUES ('9523','Production de sperme');
INSERT INTO gifi (accno,description) VALUES ('9524','Production d\'embryon');
INSERT INTO gifi (accno,description) VALUES ('9540','Revenus des paiements de programmes');
INSERT INTO gifi (accno,description) VALUES ('9541','Subventions laitires');
INSERT INTO gifi (accno,description) VALUES ('9542','Assurance-rcolte');
INSERT INTO gifi (accno,description) VALUES ('9543','Paiements du CSRN');
INSERT INTO gifi (accno,description) VALUES ('9544','Paiements provenant du programme d\'aide en cas de catastrophe');
INSERT INTO gifi (accno,description) VALUES ('9545','Indemnit du programme Agri-stabilit ou Agri-investissement');
INSERT INTO gifi (accno,description) VALUES ('9546','Indemnit de prime d\'assurance-production');
INSERT INTO gifi (accno,description) VALUES ('9570','Remises');
INSERT INTO gifi (accno,description) VALUES ('9571','Remises - carburant');
INSERT INTO gifi (accno,description) VALUES ('9572','Remises - intrt');
INSERT INTO gifi (accno,description) VALUES ('9573','Remises - taxes foncires');
INSERT INTO gifi (accno,description) VALUES ('9574','Reventes, Remises de la TPS pour les dpenses');
INSERT INTO gifi (accno,description) VALUES ('9575','Remises de la TPS pour les dpenses non');
INSERT INTO gifi (accno,description) VALUES ('9600','Autres revenus/pertes agricoles');
INSERT INTO gifi (accno,description) VALUES ('9601','Travail sur commande ou en sous-traitance');
INSERT INTO gifi (accno,description) VALUES ('9602','Ventes de bois');
INSERT INTO gifi (accno,description) VALUES ('9603','Courses de chevaux');
INSERT INTO gifi (accno,description) VALUES ('9604','Produits d\'assurance');
INSERT INTO gifi (accno,description) VALUES ('9605','Ristournes');
INSERT INTO gifi (accno,description) VALUES ('9606','Revenu de location');
INSERT INTO gifi (accno,description) VALUES ('9607','Revenu en intrt');
INSERT INTO gifi (accno,description) VALUES ('9608','Revenu de dividendes');
INSERT INTO gifi (accno,description) VALUES ('9609','Profits/pertes sur la disposition de biens');
INSERT INTO gifi (accno,description) VALUES ('9610','Gravier');
INSERT INTO gifi (accno,description) VALUES ('9611','Camionnage');
INSERT INTO gifi (accno,description) VALUES ('9612','Revente des denres achetes');
INSERT INTO gifi (accno,description) VALUES ('9613','Contrat-location (carburant, huile, puits, superficie, etc.)');
INSERT INTO gifi (accno,description) VALUES ('9614','Location de machines');
INSERT INTO gifi (accno,description) VALUES ('9615','Revenus/pertes des socits de personnes agricoles');
INSERT INTO gifi (accno,description) VALUES ('9616','Revenus/pertes des coentreprises agricoles');
INSERT INTO gifi (accno,description) VALUES ('9617','Revenu li  l\'engraissement  faon');
INSERT INTO gifi (accno,description) VALUES ('9650','Revenu non agricole');
INSERT INTO gifi (accno,description) VALUES ('9659','Total des revenus agricoles');
INSERT INTO gifi (accno,description) VALUES ('9660','Dpenses lies aux rcoltes');
INSERT INTO gifi (accno,description) VALUES ('9661','Contenants, ficelles et fils pour emballage');
INSERT INTO gifi (accno,description) VALUES ('9662','Engrais et chaux');
INSERT INTO gifi (accno,description) VALUES ('9663','Pesticides');
INSERT INTO gifi (accno,description) VALUES ('9664','Semences et plantes');
INSERT INTO gifi (accno,description) VALUES ('9665','Primes d\'assurance (rcolte) CSRN SAR');
INSERT INTO gifi (accno,description) VALUES ('9710','Dpenses lies au btail');
INSERT INTO gifi (accno,description) VALUES ('9711','Fourrage, supplments, paille et litire');
INSERT INTO gifi (accno,description) VALUES ('9712','Achats de btail');
INSERT INTO gifi (accno,description) VALUES ('9713','Frais de vtrinaire, de mdicaments et de reproduction');
INSERT INTO gifi (accno,description) VALUES ('9714','Sel et minraux');
INSERT INTO gifi (accno,description) VALUES ('9760','Dpenses lies aux machines');
INSERT INTO gifi (accno,description) VALUES ('9761','Assurance pour les machines');
INSERT INTO gifi (accno,description) VALUES ('9762','Plaques pour les machines');
INSERT INTO gifi (accno,description) VALUES ('9763','Rparation des machines');
INSERT INTO gifi (accno,description) VALUES ('9764','Carburant pour les machines');
INSERT INTO gifi (accno,description) VALUES ('9765','Contrat-location de machines');
INSERT INTO gifi (accno,description) VALUES ('9790','Dpenses agricoles gnrales');
INSERT INTO gifi (accno,description) VALUES ('9791','Amortissement des biens corporels');
INSERT INTO gifi (accno,description) VALUES ('9792','Publicit, promotion et dpenses de mise en march');
INSERT INTO gifi (accno,description) VALUES ('9793','Mauvaises crances');
INSERT INTO gifi (accno,description) VALUES ('9794','Avantages sociaux lis aux salaires des employs');
INSERT INTO gifi (accno,description) VALUES ('9795','Rparations et entretien des btiments');
INSERT INTO gifi (accno,description) VALUES ('9796','Dfrichage, nivellement et drainage de terrains');
INSERT INTO gifi (accno,description) VALUES ('9797','Primes d\'assurance-rcolte, de RARB et de');
INSERT INTO gifi (accno,description) VALUES ('9798','Travail sur commande ou en sous-traitance');
INSERT INTO gifi (accno,description) VALUES ('9799','lectricit');
INSERT INTO gifi (accno,description) VALUES ('9800','Rparations et entretien des cltures');
INSERT INTO gifi (accno,description) VALUES ('9801','Fret et camionnage');
INSERT INTO gifi (accno,description) VALUES ('9802','Combustible pour chauffage et pour salaison');
INSERT INTO gifi (accno,description) VALUES ('9803','Remboursement de paiements en trop provenant');
INSERT INTO gifi (accno,description) VALUES ('9804','Autres primes d\'assurance');
INSERT INTO gifi (accno,description) VALUES ('9805','Intrts et frais bancaires');
INSERT INTO gifi (accno,description) VALUES ('9806','Droits verss  des offices de commercialisation');
INSERT INTO gifi (accno,description) VALUES ('9807','Frais d\'adhsion');
INSERT INTO gifi (accno,description) VALUES ('9808','Dpenses de bureau');
INSERT INTO gifi (accno,description) VALUES ('9809','Honoraires professionnels');
INSERT INTO gifi (accno,description) VALUES ('9810','Taxes foncires');
INSERT INTO gifi (accno,description) VALUES ('9811','Location  terrain et btiments');
INSERT INTO gifi (accno,description) VALUES ('9812','Location  machines');
INSERT INTO gifi (accno,description) VALUES ('9813','Autres frais de location');
INSERT INTO gifi (accno,description) VALUES ('9814','Salaires et traitements');
INSERT INTO gifi (accno,description) VALUES ('9815','Salaires (autre que conjoint et personnes  charge)');
INSERT INTO gifi (accno,description) VALUES ('9816','Salaires verss aux personnes  charge');
INSERT INTO gifi (accno,description) VALUES ('9817','Cots des ventes');
INSERT INTO gifi (accno,description) VALUES ('9818','Fournitures');
INSERT INTO gifi (accno,description) VALUES ('9819','Dpenses concernant les vhicules motoriss');
INSERT INTO gifi (accno,description) VALUES ('9820','Petit outillage');
INSERT INTO gifi (accno,description) VALUES ('9821','Analyses des sols');
INSERT INTO gifi (accno,description) VALUES ('9822','Entreposage/schage');
INSERT INTO gifi (accno,description) VALUES ('9823','Licences/permis');
INSERT INTO gifi (accno,description) VALUES ('9824','Tlphone');
INSERT INTO gifi (accno,description) VALUES ('9825','Location de contingents (tabac, laitier)');
INSERT INTO gifi (accno,description) VALUES ('9826','Gravier');
INSERT INTO gifi (accno,description) VALUES ('9827','Achats de produits pour la revente');
INSERT INTO gifi (accno,description) VALUES ('9828','Salaires et traitements pays au conjoint');
INSERT INTO gifi (accno,description) VALUES ('9829','Cots de location et intrt sur un vhicule');
INSERT INTO gifi (accno,description) VALUES ('9830','Aliments prpars');
INSERT INTO gifi (accno,description) VALUES ('9831','Engraissement  forfait');
INSERT INTO gifi (accno,description) VALUES ('9832','Amortissement des biens incorporels');
INSERT INTO gifi (accno,description) VALUES ('9833','Amortissement de quote-part de lait');
INSERT INTO gifi (accno,description) VALUES ('9834','Frais de dplacement');
INSERT INTO gifi (accno,description) VALUES ('9835','Taxes d\'affaires/sur le capital');
INSERT INTO gifi (accno,description) VALUES ('9836','Commissions et redevances');
INSERT INTO gifi (accno,description) VALUES ('9850','Dpenses non agricoles');
INSERT INTO gifi (accno,description) VALUES ('9870','Rgularisation des stocks');
INSERT INTO gifi (accno,description) VALUES ('9898','Total des dpenses agricoles');
INSERT INTO gifi (accno,description) VALUES ('9899','Total-autres revenus tendus');
INSERT INTO gifi (accno,description) VALUES ('9970','Revenu net/perte nette avant impts et lments');
INSERT INTO gifi (accno,description) VALUES ('9975','lment(s) extraordinaire(s)');
INSERT INTO gifi (accno,description) VALUES ('9976','Rglements juridiques');
INSERT INTO gifi (accno,description) VALUES ('9980','Profits/pertes non matrialiss');
INSERT INTO gifi (accno,description) VALUES ('9985','lments inhabituels');
INSERT INTO gifi (accno,description) VALUES ('9990','Impts sur le revenu exigibles de l\'exercice');
INSERT INTO gifi (accno,description) VALUES ('9995','Provision pour impts sur le revenu diffrs');
INSERT INTO gifi (accno,description) VALUES ('9998','Total-autres revenus tendus');
INSERT INTO gifi (accno,description) VALUES ('9999','Revenu net/perte nette aprs impts et lments');
